/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

(function($, Backbone, _, dm){
    
    "use strict";
    
    dm.ViewProcess = Backbone.View.extend({
        
        initialize: function () {
            this.line = new dm.ViewProgress({el: this.$('.processing').first(), model: this.model});
            this.help = new dm.ViewProcessingHelp({el: this.$('.help-wrapper').first(), model: this.model});
            this.listenTo(this.model, 'change', this.progress);
            this.listenTo(this.model, 'processing-error', this.prosessingError);
            this.listenTo(this.model, 'processing-start', this.prosessingStart);
            this.progress();
        },
        
        progress: function () {
            var position = this.model.get('current_progress');
            var counts = this.model.get('counts');
            var title = this.model.get('process_name');
            var logs = this.model.get('log');
            
            if (position === null) {
                this.$el.hide();
                return;
            } else {
                this.$el.show();
            }
            
            // Write details
            this.$('.current-count').html(position);
            this.$('.all-count').html(counts);
            this.$('.process-name').html(title);
            
            // Write log
            var self = this;
            var log_html = '';
            _.each(logs, function(message, index){
                
                if (message.error) {
                    log_html += '<span class="text-danger"><i class="fa fa-exclamation-triangle" aria-hidden="true"></i> ';
                }
                
                log_html += message.message + '\n';
                
                if (message.error) {
                    log_html += '</span>';
                }
                
                if (logs.length - 1 === index) {
                    self.$('.process-header .log span').html(message.message);
                }
                
                if (message.error) {
                    self.$('.process-header .log span').addClass('text-danger');
                } else {
                    self.$('.process-header .log span').removeClass('text-danger');
                }
                
            });
            this.$('.log-wrapper pre').html(log_html);
        },
        
        events: {
            'click .action-continue' : 'processing',
            'click .action-abort' : 'aborting',
            'click .action-kill' : 'kill'
        },
        
        processing: function () {
            this.model.processing();
            return false;
        },
        
        aborting: function () {
            this.model.aborting();
            return false;
        },
        
        kill: function () {
            this.model.kill();
            return false;
        },
        
        prosessingError: function () {
            this.$('.process-header .log').hide();
            this.$('.process-details').show();
        },
        
        prosessingStart: function () {
            this.$('.process-header .log').show();
            this.$('.process-details').hide();
        }
        
    });
   
})(jQuery, Backbone, _, window.wp_demo_manager);

