<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM;

use DM\Data;

class Config
{
    private static $_instance = null;
    
    protected $defaults = array();
    
    /**
     * @return \DM\Config
     */
    static public function getInstance()
    {
        if (is_null(self::$_instance)) {
            self::$_instance = new self();
        }
        
        return self::$_instance;
    }
    
    public function getSettingValue($key)
    {
        $value = Data::getData($key);
        if (!is_null($value)) {
            return $value;
        } elseif (!is_null($this->getDefaultValue($key))) {
            return $this->getDefaultValue($key);
        }
        
        return null;
    }
    
    public function getDefaultValue($key = null)
    {
        $defaults = apply_filters('wp_demo_manager_default_config', $this->defaults);
        
        if (is_null($key)) {
            return $defaults;
        }
        
        if (isset($defaults[$key])) {
            return $defaults[$key];
        }
        
        return false;
    }
    
    public function getRepositoryCollectionUrl()
    {
        return $this->getRepositoryUrl() . 'list.json?ver=' . time();
    }
    
    public function hasRepository()
    {
        if (!$this->getRepositoryUrl()) {
            return false;
        }
        
        return true;
    }
    
    public function getRepositoryUrl()
    {
        return $this->getSettingValue('repository_url');
    }
    
    public function getUploadDemoUrl($demo_id, $version)
    {
        return $this->getRepositoryUrl() . $demo_id . '.zip?v=' . $version;
    }
    
    public function getLibraryName()
    {
        return $this->getSettingValue('repository_library_name');
    }
    
    public function getPluginRootDir()
    {
        if (defined('WP_DEMO_MANAGER_PATH')) {
            return WP_DEMO_MANAGER_PATH;
        }
        
        return false;
    }
    
    public function getLocalDataPath()
    {
        if (defined('WP_DEMO_MANAGER_LOCAL_PATH')) {
            if (!is_dir(WP_DEMO_MANAGER_LOCAL_PATH) && !mkdir(WP_DEMO_MANAGER_LOCAL_PATH)) {
                throw new \Exception("Create local data folder: no permission to file create");
            }
            
            return WP_DEMO_MANAGER_LOCAL_PATH;
        }
        
        return false;
        /*
        $contents_dir = self::searchParentDir(dirname(__FILE__), 'wp-content');
        if (!$contents_dir) {
            return false;
        }
        
        return $contents_dir . '/wp_demo_manager/';*/
    }
    
    /*
    static public function searchParentDir($current_name, $target)
    {
        if (!\is_dir($current_name)) {
            return false;
        }
        
        $parent = \dirname( $current_name );
        if (basename($parent) !== $target) {
            return self::searchParentDir($parent, $target);
        }
        
        return $parent;
    }*/
    
    public function getDemosDir()
    {
        $local_data_path = $this->getLocalDataPath();
        if (!$local_data_path) {
            return false;
        }
        
        $path =  $local_data_path . 'dumps/';
        
        if (!is_dir($path) && !mkdir($path)) {
            throw new \Exception("Create local demo storage folder: no permission to file create");
        }
        
        return $path;
    }
    
    public function getLogPath()
    {
        $local_data_path = $this->getLocalDataPath();
        if (!$local_data_path) {
            return false;
        }
        
        return $local_data_path . 'log.json';
    }
    
    public function getLogUrl()
    {
        return WP_CONTENT_URL . '/wp_demo_manager/log.json';
    }
    
    public function getDataPath()
    {
        $local_data_path = $this->getLocalDataPath();
        if (!$local_data_path) {
            return false;
        }
        
        return $local_data_path . 'data.json';
    }
    
    public function isMultiSite()
    {
        return $this->getSettingValue('enable_multisite_mode') ? true : false;
    }
    
    public function isDevelopMode()
    {
        return $this->getSettingValue('enable_develop_mod') ? true : false;
    }
}