<?php

/**
 * @encoding     UTF-8
 * @package      WordPress Demo Content Manager
 * @link         https://codecanyon.net/item/wordpress-demo-content-manager/20669604
 * @copyright    Copyright (C) 2018 Torbara (http://torbara.com). All rights reserved.
 * @license      Envato Standard License http://themeforest.net/licenses/standard?ref=torbara
 * @author       Vladislav Dolgolenko <vladislavdolgolenko.com>
 * @support      <help@vladislavdolgolenko.com>
 */

namespace DM\Processing\Steps;

use DM\Processing\Step;
use DM\Service;

class CreateDbTables extends Step
{
    protected function processing()
    {
        global $table_prefix;
        
        if (!$table_prefix) {
            throw new \Exception('Default table prefix not found in file wp-config.');
        }
        
        $this->getLog()->addLog('Creating tables in the database');
        $this->createTables();
        
        return true;
    }
    
    protected function abort()
    {
        $this->getLog()->addLog('Deleting tables in a database with demo data content');
        
        $table_list = Service::getCurrentWordpressDbTables($this->getDemo()->getTablePrefix());
        foreach ($table_list as $table_name) {
            $this->getDB()->query("DROP TABLE IF EXISTS `" . $table_name . "`;");
        }
        
        return true;
    }
    
    public function createTables()
    {
        $tables = $this->getDemo()->getTablesList();
        $table_structure_query = str_replace('utf8mb4_unicode_520_ci', 'utf8mb4_unicode_ci', $this->getDemo()->getStructureSql());
        
        if (!is_array($tables) || count($tables) < 11) {
            throw new \Exception('Undefined demo creation tables list');
        }
            
        if ($this->getDB()->dbh instanceof \mysqli) {
        
            mysqli_multi_query($this->getDB()->dbh, $table_structure_query);
            do {
                if($result = mysqli_store_result($this->getDB()->dbh)){
                    mysqli_free_result($result);
                }
            } while(@mysqli_next_result($this->getDB()->dbh));
            
        } else {
            
            $array_querys = explode(";", $table_structure_query);
            foreach ($array_querys as $create_table_query) {
                if (strpos($create_table_query, "CREATE TABLE") === false) {
                    continue;
                }
                $this->getDB()->query($create_table_query);
            }
            
        }
        
        $result = $this->getDemo()->hasDatabaseTables();
        if ($result !== true) {
            throw new \Exception("Demo database structure: could not create database table $result!");
        }
    }
}

